==> e16_1.0.0.orig.tar.gz: e16-1.0.0/src/tooltips.h <==
/*
 * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
 * Copyright (C) 2004-2007 Kim Woelders
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _TOOLTIPS_H_
#define _TOOLTIPS_H_

#include "etypes.h"

typedef struct _tooltip ToolTip;

typedef ActionClass *(CB_GetAclass) (void *data);

int                 TooltipConfigLoad(FILE * fs);

void                TooltipShow(ToolTip * tt, const char *text,
				ActionClass * ac, int x, int y);
void                TooltipHide(ToolTip * tt);

ToolTip            *TooltipFind(const char *name);

void                TooltipsSetPending(int type, CB_GetAclass * func,
				       void *data);
void                TooltipsHide(void);
void                TooltipsEnable(int enable);

#endif /* _TOOLTIPS_H_ */

==> e16-1.0.31.tar.gz: e16-1.0.31/src/tooltips.h <==
/*
 * Copyright (C) 2000-2007 Carsten Haitzler, Geoff Harrison and various contributors
 * Copyright (C) 2004-2007 Kim Woelders
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _TOOLTIPS_H_
#define _TOOLTIPS_H_

#include "etypes.h"

typedef struct _tooltip ToolTip;

typedef ActionClass *(CB_GetAclass) (void *data);

int             TooltipConfigLoad(FILE * fs);

void            TooltipShow(ToolTip * tt, const char *text,
                            ActionClass * ac, int x, int y);
void            TooltipHide(ToolTip * tt);

ToolTip        *TooltipFind(const char *name);

void            TooltipsSetPending(int type, CB_GetAclass * func, void *data);
void            TooltipsHide(void);
void            TooltipsEnable(int enable);

#endif                          /* _TOOLTIPS_H_ */
